@@ -230,8 +230,24 @@ class NERDA:
         # TODO: change assert to Raise.
         assert os.path.exists(model_path), "File does not exist. You can download network with download_network()"
         self.network.load_state_dict(torch.load(model_path, map_location = torch.device(self.device)))
+        self.network.device = self.device
         return f'Weights for network loaded from {model_path}'
 
+    def save_network(self, model_path:str = "model.bin") -> None:
+        """Save Weights of NERDA Network
+
+        Saves weights for a fine-tuned NERDA Network to file.
+
+        Args:
+            model_path (str, optional): Path for model file. 
+                Defaults to "model.bin".
+
+        Returns:
+            Nothing. Saves model to file as a side-effect.
+        """
+        torch.save(self.network.state_dict(), model_path)
+        print(f"Network written to file {model_path}")
+
     def quantize(self):
         """Apply dynamic quantization to increase performance.
 
@@ -266,7 +282,9 @@ class NERDA:
         self.network.half()
         self.halved = True
 
-    def predict(self, sentences: List[List[str]], **kwargs) -> List[List[str]]:
+    def predict(self, sentences: List[List[str]],
+                return_confidence: bool = False,
+                **kwargs) -> List[List[str]]:
         """Predict Named Entities in Word-Tokenized Sentences
 
         Predicts word-tokenized sentences with trained model.
@@ -275,6 +293,9 @@ class NERDA:
             sentences (List[List[str]]): word-tokenized sentences.
             kwargs: arbitrary keyword arguments. For instance
                 'batch_size' and 'num_workers'.
+            return_confidence (bool, optional): if True, return
+                confidence scores for all predicted tokens. Defaults
+                to False.
 
         Returns:
             List[List[str]]: Predicted tags for sentences - one
@@ -288,15 +309,20 @@ class NERDA:
                        device = self.device,
                        tag_encoder = self.tag_encoder,
                        tag_outside = self.tag_outside,
+                       return_confidence = return_confidence,
                        **kwargs)
 
-    def predict_text(self, text: str, **kwargs) -> list:
+    def predict_text(self, text: str, 
+                     return_confidence:bool = False, **kwargs) -> list:
         """Predict Named Entities in a Text
 
         Args:
             text (str): text to predict entities in.
             kwargs: arbitrary keyword arguments. For instance
                 'batch_size' and 'num_workers'.
+            return_confidence (bool, optional): if True, return
+                confidence scores for all predicted tokens. Defaults
+                to False.
 
         Returns:
             tuple: word-tokenized sentences and predicted 
@@ -310,6 +336,7 @@ class NERDA:
                             device = self.device,
                             tag_encoder = self.tag_encoder,
                             tag_outside = self.tag_outside,
+                            return_confidence=return_confidence,
                             **kwargs)
 
     def evaluate_performance(self, dataset: dict, 
