@@ -12,6 +12,10 @@ from typing import List, Callable
 import transformers
 import sklearn.preprocessing
 
+def sigmoid_transform(x):
+    prob = 1/(1 + np.exp(-x))
+    return prob
+
 def predict(network: torch.nn.Module, 
             sentences: List[List[str]],
             transformer_tokenizer: transformers.PreTrainedTokenizer,
@@ -23,6 +27,7 @@ def predict(network: torch.nn.Module,
             batch_size: int = 8,
             num_workers: int = 1,
             return_tensors: bool = False,
+            return_confidence: bool = False,
             pad_sequences: bool = True) -> List[List[str]]:
     """Compute predictions.
 
@@ -48,6 +53,9 @@ def predict(network: torch.nn.Module,
         num_workers (int, optional): Number of workers. Defaults
             to 1.
         return_tensors (bool, optional): if True, return tensors.
+        return_confidence (bool, optional): if True, return
+            confidence scores for all predicted tokens. Defaults
+            to False.
         pad_sequences (bool, optional): if True, pad sequences. 
             Defaults to True.
 
@@ -79,6 +87,7 @@ def predict(network: torch.nn.Module,
                            pad_sequences = pad_sequences)
 
     predictions = []
+    probabilities = []
     tensors = []
     
     with torch.no_grad():
@@ -90,18 +99,25 @@ def predict(network: torch.nn.Module,
             for i in range(outputs.shape[0]):
                 
                 # extract prediction and transform.
-                preds = tag_encoder.inverse_transform(
-                    outputs[i].argmax(-1).cpu().numpy()
-                )
+
+                # find max by row.
+                values, indices = outputs[i].max(dim=1)
+                
+                preds = tag_encoder.inverse_transform(indices.cpu().numpy())
+                probs = values.cpu().numpy()
 
                 if return_tensors:
                     tensors.append(outputs)    
 
                 # subset predictions for original word tokens.
                 preds = [prediction for prediction, offset in zip(preds.tolist(), dl.get('offsets')[i]) if offset]
+                if return_confidence:
+                    probs = [prob for prob, offset in zip(probs.tolist(), dl.get('offsets')[i]) if offset]
             
                 # Remove special tokens ('CLS' + 'SEP').
                 preds = preds[1:-1]
+                if return_confidence:
+                    probs = probs[1:-1]
             
                 # make sure resulting predictions have same length as
                 # original sentence.
@@ -109,8 +125,12 @@ def predict(network: torch.nn.Module,
                 # TODO: Move assert statement to unit tests. Does not work 
                 # in boundary.
                 # assert len(preds) == len(sentences[i])            
-
                 predictions.append(preds)
+                if return_confidence:
+                    probabilities.append(probs)
+            
+            if return_confidence:
+                return predictions, probabilities
 
             if return_tensors:
                 return tensors
@@ -128,6 +148,7 @@ def predict_text(network: torch.nn.Module,
                  batch_size: int = 8,
                  num_workers: int = 1,
                  pad_sequences: bool = True,
+                 return_confidence: bool = False,
                  sent_tokenize: Callable = sent_tokenize,
                  word_tokenize: Callable = word_tokenize) -> tuple:
     """Compute Predictions for Text.
@@ -154,6 +175,9 @@ def predict_text(network: torch.nn.Module,
             to 1.
         pad_sequences (bool, optional): if True, pad sequences. 
             Defaults to True.
+        return_confidence (bool, optional): if True, return 
+            confidence scores for predicted tokens. Defaults
+            to False.
 
     Returns:
         tuple: sentence- and word-tokenized text with corresponding
@@ -170,6 +194,7 @@ def predict_text(network: torch.nn.Module,
                           transformer_config = transformer_config,
                           max_len = max_len,
                           device = device,
+                          return_confidence = return_confidence,
                           batch_size = batch_size,
                           num_workers = num_workers,
                           pad_sequences = pad_sequences,
